MetricResults
=============

.. currentmodule:: pykeen.evaluation

.. autoclass:: MetricResults
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MetricResults.get_metric
      ~MetricResults.key_from_string
      ~MetricResults.key_to_string
      ~MetricResults.string_or_key_to_key
      ~MetricResults.to_df
      ~MetricResults.to_dict
      ~MetricResults.to_flat_dict

   .. rubric:: Methods Documentation

   .. automethod:: get_metric
   .. automethod:: key_from_string
   .. automethod:: key_to_string
   .. automethod:: string_or_key_to_key
   .. automethod:: to_df
   .. automethod:: to_dict
   .. automethod:: to_flat_dict
